<?php
// $Id: luceneapi_node.facet.inc,v 1.3.2.3 2009/03/12 23:47:35 cpliakas Exp $

/**
 * @file
 * Facet queries for the Search Lucene Content module.
 */

/**
 * Appends a query for the content type facet.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet queries.
 * @return
 *   NULL
 */
function _luceneapi_node_append_type_query(Zend_Search_Lucene_Search_Query_Boolean $query) {
  $types = luceneapi_facet_value('type', array());
  if (is_array($types) && !empty($types)) {

    // instantiates multiterm query, adds content types as terms
    $type_query = luceneapi_query_get('multiterm');
    foreach ($types as $type) {
      if ($type) {
        luceneapi_add_term($type_query, luceneapi_term_get($type, 'type'));
      }
    }

    // if terms were added, sets boost and appends to facet query
    if (count($type_query->getTerms())) {
      $type_query->setBoost(1E-9); // makes irrelavent in score calculation
      luceneapi_add_subquery($query, $type_query, 'required');
    }
  }
}

/**
 * Appends query for the taxonomy facet.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet
 *   queries.
 * @return
 *   NULL
 */
function _luceneapi_node_append_taxonomy_query(Zend_Search_Lucene_Search_Query_Boolean $query) {
  $terms = luceneapi_facet_value('category', array());
  if (is_array($terms) && !empty($terms)) {

    // instantiates multiterm query, adds content types as terms
    $term_query = luceneapi_query_get('multiterm');
    foreach ($terms as $term_id) {
      if ($term_id) {
        luceneapi_add_term($term_query, luceneapi_term_get($term_id, 'category'));
      }
    }

    // if terms were added, sets boost and appends to facet query
    if (count($term_query->getTerms())) {
      $term_query->setBoost(1E-9); // makes irrelavent in score calculation
      luceneapi_add_subquery($query, $term_query, 'required');
    }
  }
}

/**
 * Appends query for the node arthors.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet
 *   queries.
 * @return
 *   NULL
 * @todo tighten up the parsing, figure out spaces in users
 */
function _luceneapi_node_append_user_query(Zend_Search_Lucene_Search_Query_Boolean $query) {
  $users = luceneapi_facet_value('author');
  if (!empty($users)) {

    // instantiates author query, splits author name by comma
    $author_query = luceneapi_query_get('boolean');
    $parsed = array_map('trim', explode(',', (string)$users));

    // adds authors as wildcard subqueries
    foreach ($parsed as $name) {
      if (drupal_strlen($name)) {
        luceneapi_add_subquery($author_query, luceneapi_query_get(
          'wildcard', drupal_strtolower($name), 'name'
        ));
      }
    }

    // if queries were added, appends to facet queries
    if (count($author_query->getSubqueries())) {
      luceneapi_add_subquery($query, $author_query, 'required');
    }
  }
}

/**
 * Appends query for changed after facet.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet
 *   queries.
 * @return
 *   NULL
 * @see _luceneapi_node_append_date_subquery()
 */
function _luceneapi_node_append_changed_query(Zend_Search_Lucene_Search_Query_Boolean $query) {
  _luceneapi_node_append_date_subquery('changed', $query);
}

/**
 * Appends query for created after facet.
 *
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet
 *   queries.
 * @return
 *   NULL
 * @see _luceneapi_node_append_date_subquery()
 */
function _luceneapi_node_append_created_query(Zend_Search_Lucene_Search_Query_Boolean $query) {
  _luceneapi_node_append_date_subquery('created', $query);
}

/**
 * Provides common functionality for date facets, appends facets.
 *
 * @param $field
 *   A string containing the name of the search field that corresponds with the
 *   name of the index field being searched.
 * @param $query
 *   A Zend_Search_Lucene_Search_Query_Boolean object containing the facet
 *   queries.
 * @return
 *   NULL
 */
function _luceneapi_node_append_date_subquery($field, Zend_Search_Lucene_Search_Query_Boolean $query) {
  $usertime = luceneapi_facet_value($field, '');
  if (!empty($usertime)) {
    if (date_is_valid((string)$usertime, DATE_DATETIME)) {
      $unixtime = date_convert($usertime, DATE_DATETIME, DATE_UNIX);
      $range_query = luceneapi_query_get('range', $unixtime, time(), FALSE, $field);
      luceneapi_add_subquery($query, $range_query, 'required');
    }
    else {
      form_set_error($field, sprintf('Date not valid for %s field', $field));
      return;
    }
  }
}
