<?php
// $Id: luceneapi.help.inc,v 1.2.2.3 2009/03/08 19:48:28 cpliakas Exp $

/**
 * @file
 * Functions that return larger blocks of help text.
 */

/**
 * Returns help for the Search Lucene API module.
 *
 * @return
 *   A string containing the translated help text.
 */
function _luceneapi_help_module() {
  return t('
    <p>
    Search Lucene API is an interface for modules to index and search content
    using a Lucene backend. Search Lucene API integrates the Zend Framework\'s
    Zend_Search_Lucene component to provide a native PHP implementation of the
    Apache Lucene project. This module is an extension of the core Search API so
    that sites can seamlessly transition to a more advanced search, and
    developers can create Search Lucene API modules on top of a familiar
    framework.  Search Lucene API modules share a common group of admin settings
    used to tweak index performance, maintenance, and behavior.
    </p>

    <h4>Search Lucene API Settings</h4>
    <p>The <i>global settings</i> apply to all Search Lucene API modules.</p>
    <ul>
      <li><b>Hijack search box</b> overrides the core search box and search
      block so that they are directed to the selected Search Lucene API module.
      This functionality is accomplished internally by appending submit handlers
      that point the redirection path to the selected module\'s search page.
      </li>
      <li><b>Result set limit</b> limits the number of results that scores are
      calculated for.  For large result sets, setting a limit can greatly reduce
      the amount of time it takes to execute the search. Note that the first
      <i>N</i> results are returned, not the best <i>N</i> results.</li>
    </ul>
    <p>The <i>error settings</i> are used to configure how internal application
    errors are handled.  For development sites, detailed error messages should
    be displayed.  In production environments, either a general error message
    or no error message should be displayed for security reasons.</p>

    <h4>Common Settings Used By Search Lucene API Modules</h4>
    <p>The <i>index settings</i> configure index location and maintenance.</p>
    <ul>
      <li><b>Index path</b> is the path on the filesystem where the index
      actually lives.  Appropriate steps should be taken to ensure the index is
      not publicly accessible.</li>
      <li><b>Items to index per update</b> are the maximum number of items that
      will be indexed per update.  This should be set to a lower value if the
      update process runs out of memory.</li>
      <li><b>Update index via cron</b> enables or disables updates via cron. If
      cron updates are disabled, the index may be updated via Drush by executing
      the <code>drush luceneapi update `module_name`</code> command.</li>
      <li><b>Optimize on update</b> automatically optimizes the index after it
      is updated.  Turning this setting on eliminates the need to perform manual
      optimizations, but it may have to be turned off if cron times out or runs
      out of memory.</li>
      <li>The <b>optimize index</b> button consolidates index segments so that
      the index becomes more efficient.  Optimization may take a long time for
      larger, fragmented indexes.  It is safe to optimize the index in
      production environments.</li>
    </ul>
    <p>The <i>search page settings</i> configure the search results page.</p>
    <ul>
      <li><b>Results per page</b> are the number of results displayed per page
      in a paginated search result set.  This functionality is accomplished by
      auto-implementing hook_search_page() to allow the pager limit to be passed
      to theme_pager().</li>
    </ul>
    <p><i>Cache settings</i> configure the built in result set caching
    mechanism.</p>
    <ul>
      <li><b>Enable caching</b> determines whether the caching mechanism will be
      utilized.  For sites that have a chance of repeated queries, caching will
      greatly improve performance and reduce memory consumption, especially for
      larger indexes.  If items have been updated or added since the last index
      update, the cache is cleared after the update process finishes.</li>
      <li><b>Maximum size of cached result set</b> is the maximum number of
      items in the result set that will be cached.  No matter how large the
      result set, only the first <i>N</i> number of results will be cached.
      Changing the setting to a lower value will improve the performance of the
      cache.</li>
      <li>The <b>clear search results cache</b> button wipes out the cached
      result sets for the module.  Cached result sets for other modules will
      remain active in the cache table.</li>
    </ul>
    <p>The <i>facet settings</i> configure which facets will be used in the
    search, if any.</p>
    <ul>
      <li><b>Enable faceted searches</b> enables or disables faceted searches
      on the module\'s search page.</li>
      <li><b>Enable facets</b> configures which facets are displayed on the
      module\'s search page.  Facets are made available via Facet API which is
      built into Search Lucene API.</li>
    </ul>
  ');
}